Instance source is the template used to create an instance. You can use an image, a snapshot of an instance (image snapshot), a volume or a volume snapshot (if enabled). You can also choose to use persistent storage by creating a new volume.

Select Boot Source
{$ ctrl.bootSourceTypeError $}
Create New Volume
{$ ::option.label $}
Delete Volume on Instance Delete
{$ ::option.label $}
Volume Size (GB) {$ launchInstanceSourceForm['volume-size'].$error.validateNumberMin ? ctrl.minVolumeSizeError : ctrl.volumeSizeError $}
Delete Volume on Instance Delete
{$ ::option.label $}
Device Name
There are no allowed boot sources. If you think this is wrong please contact your administrator.